.. currentmodule:: fastscapelib

:orphan:

.. autosummary::
   :toctree: _api_generated/

   MSTMethod
   MSTRouteMethod
   flow.numba.flow_kernel.NumbaFlowKernel
   flow.numba.flow_kernel.NumbaFlowKernelData
   flow.numba.flow_kernel.NumbaFlowKernelData.bind
   flow.numba.flow_kernel.NumbaFlowKernelData.check_bindings
   flow.numba.flow_kernel.NumbaFlowKernelData.var_names
   flow.numba.flow_kernel.NumbaFlowKernelData.grid_var_names
   flow.numba.flow_kernel.NumbaFlowKernelData.kernel_data
   flow.numba.flow_kernel.NumbaFlowKernelData.jitclass_obj
